Module reductions

Module reductions 

Traits

MeanAcc
Maps an element type T to the type NumPy uses to accumulate (and return) mean over it.
ReduceAcc
Maps an element type T to the type NumPy uses to accumulate (and return) sum / prod / cumsum / cumprod over it.