Skip to main contentModule dimension
Source - broadcast
- Axis
- Newtype for axis indices used throughout ferray.
- Ix0
- A zero-dimensional (scalar) dimension.
- Ix1
- A fixed-rank dimension with
1 axes.
- Ix2
- A fixed-rank dimension with
2 axes.
- Ix3
- A fixed-rank dimension with
3 axes.
- Ix4
- A fixed-rank dimension with
4 axes.
- Ix5
- A fixed-rank dimension with
5 axes.
- Ix6
- A fixed-rank dimension with
6 axes.
- IxDyn
- A dynamic-rank dimension whose number of axes is determined at runtime.
- Dimension
- Trait for types that describe the dimensionality of an array.