pub enum PadMode<T: Element> {
Constant(T),
Edge,
Reflect,
Symmetric,
Wrap,
}Expand description
Padding mode for pad.
Variants
Constant(T)
Pad with a constant value.
Edge
Pad with the edge values of the array.
Reflect
Pad with the reflection of the array mirrored on the first and last values (does not repeat the edge).
Symmetric
Pad with the reflection of the array mirrored along the edge.
Wrap
Pad by wrapping the array around.