stack

Function stack 

pub fn stack<T: Element>(
    arrays: &[Array<T, IxDyn>],
    axis: usize,
) -> FerrayResult<Array<T, IxDyn>>
Join a sequence of arrays along a new axis.

All arrays must have the same shape. The result has one more dimension than the inputs.

Analogous to numpy.stack().

Errors

Returns FerrayError::InvalidValue if the array list is empty. Returns FerrayError::ShapeMismatch if shapes differ. Returns FerrayError::AxisOutOfBounds if axis > ndim.