Module ops

Module ops 

Functions

copyto
Copy values from src into dst, broadcasting src to dst.shape().
copyto_where
Copy values from src into dst where mask is true, broadcasting both src and mask to dst.shape().