Skip to main contentModule creation
Source - UninitArray
- An array whose elements have not been initialized.
- ArangeNum
- Trait for types usable with
arange — numeric types that support
stepping and comparison. - LinspaceNum
- Trait for float-like types used in linspace/logspace/geomspace.
- arange
- Create a 1-D array with evenly spaced values within a given interval.
- array
- Create an array from a flat vector and a shape (C-order).
- asarray
- Interpret existing data as an array without copying (if possible).
- diag
- Extract a diagonal or construct a diagonal array.
- diagflat
- Create a 2-D array with the flattened input as a diagonal.
- empty
- Create an uninitialized array.
- eye
- Create a 2-D array with ones on the diagonal and zeros elsewhere.
- frombuffer
- Create an array from a byte buffer, interpreting bytes as elements of type
T. - fromiter
- Create a 1-D array from an iterator.
- full
- Create an array filled with a given value.
- full_like
- Create an array with the same shape as
other, filled with fill_value. - geomspace
- Create a 1-D array with values spaced evenly on a geometric (log) scale.
- identity
- Create a 2-D identity matrix of size
n x n. - linspace
- Create a 1-D array with
num evenly spaced values between start and stop. - logspace
- Create a 1-D array with values spaced evenly on a log scale.
- meshgrid
- Return coordinate arrays from coordinate vectors.
- mgrid
- Create a dense multi-dimensional “meshgrid” with matrix (‘ij’) indexing.
- ogrid
- Create a sparse (open) multi-dimensional “meshgrid” with ‘ij’ indexing.
- ones
- Create an array filled with ones.
- ones_like
- Create an array with the same shape as
other, filled with ones. - tri
- Create a lower-triangular matrix of ones.
- tril
- Return the lower triangle of a 2-D array.
- triu
- Return the upper triangle of a 2-D array.
- zeros
- Create an array filled with zeros.
- zeros_like
- Create an array with the same shape as
other, filled with zeros.