stack

Function stack 

pub fn stack<T: Element>(
    arrays: &[Array<T, IxDyn>],
    axis: usize,
) -> FerrumResult<Array<T, IxDyn>>
Join a sequence of arrays along a new axis.

All arrays must have the same shape. The result has one more dimension than the inputs.

Analogous to numpy.stack().

Errors

Returns FerrumError::InvalidValue if the array list is empty. Returns FerrumError::ShapeMismatch if shapes differ. Returns FerrumError::AxisOutOfBounds if axis > ndim.